#[non_exhaustive]pub struct CreateLaunchProfileInput {
pub client_token: Option<String>,
pub description: Option<String>,
pub ec2_subnet_ids: Option<Vec<String>>,
pub launch_profile_protocol_versions: Option<Vec<String>>,
pub name: Option<String>,
pub stream_configuration: Option<StreamConfigurationCreate>,
pub studio_component_ids: Option<Vec<String>>,
pub studio_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
description: Option<String>The description.
ec2_subnet_ids: Option<Vec<String>>Specifies the IDs of the EC2 subnets where streaming sessions will be accessible from. These subnets must support the specified instance types.
launch_profile_protocol_versions: Option<Vec<String>>The version number of the protocol that is used by the launch profile. The only valid version is "2021-03-31".
name: Option<String>The name for the launch profile.
stream_configuration: Option<StreamConfigurationCreate>A configuration for a streaming session.
studio_component_ids: Option<Vec<String>>Unique identifiers for a collection of studio components that can be used with this launch profile.
studio_id: Option<String>The studio ID.
A collection of labels, in the form of key-value pairs, that apply to this resource.
Implementations
Sourceimpl CreateLaunchProfileInput
impl CreateLaunchProfileInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description.
Sourcepub fn ec2_subnet_ids(&self) -> &[String]
pub fn ec2_subnet_ids(&self) -> &[String]
Specifies the IDs of the EC2 subnets where streaming sessions will be accessible from. These subnets must support the specified instance types.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .ec2_subnet_ids.is_none().
Sourcepub fn launch_profile_protocol_versions(&self) -> &[String]
pub fn launch_profile_protocol_versions(&self) -> &[String]
The version number of the protocol that is used by the launch profile. The only valid version is "2021-03-31".
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .launch_profile_protocol_versions.is_none().
Sourcepub fn stream_configuration(&self) -> Option<&StreamConfigurationCreate>
pub fn stream_configuration(&self) -> Option<&StreamConfigurationCreate>
A configuration for a streaming session.
Sourcepub fn studio_component_ids(&self) -> &[String]
pub fn studio_component_ids(&self) -> &[String]
Unique identifiers for a collection of studio components that can be used with this launch profile.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .studio_component_ids.is_none().
A collection of labels, in the form of key-value pairs, that apply to this resource.
Sourceimpl CreateLaunchProfileInput
impl CreateLaunchProfileInput
Sourcepub fn builder() -> CreateLaunchProfileInputBuilder
pub fn builder() -> CreateLaunchProfileInputBuilder
Creates a new builder-style object to manufacture CreateLaunchProfileInput.