pub struct CreateStreamingSessionFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateStreamingSession.
Creates a streaming session in a studio.
After invoking this operation, you must poll GetStreamingSession until the streaming session is in the READY state.
Implementations
Sourceimpl CreateStreamingSessionFluentBuilder
impl CreateStreamingSessionFluentBuilder
Sourcepub fn as_input(&self) -> &CreateStreamingSessionInputBuilder
pub fn as_input(&self) -> &CreateStreamingSessionInputBuilder
Access the CreateStreamingSession as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateStreamingSessionOutput, SdkError<CreateStreamingSessionError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateStreamingSessionOutput, SdkError<CreateStreamingSessionError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateStreamingSessionOutput, CreateStreamingSessionError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateStreamingSessionOutput, CreateStreamingSessionError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn ec2_instance_type(self, input: StreamingInstanceType) -> Self
pub fn ec2_instance_type(self, input: StreamingInstanceType) -> Self
The EC2 Instance type used for the streaming session.
Sourcepub fn set_ec2_instance_type(self, input: Option<StreamingInstanceType>) -> Self
pub fn set_ec2_instance_type(self, input: Option<StreamingInstanceType>) -> Self
The EC2 Instance type used for the streaming session.
Sourcepub fn get_ec2_instance_type(&self) -> &Option<StreamingInstanceType>
pub fn get_ec2_instance_type(&self) -> &Option<StreamingInstanceType>
The EC2 Instance type used for the streaming session.
Sourcepub fn launch_profile_id(self, input: impl Into<String>) -> Self
pub fn launch_profile_id(self, input: impl Into<String>) -> Self
The ID of the launch profile used to control access from the streaming session.
Sourcepub fn set_launch_profile_id(self, input: Option<String>) -> Self
pub fn set_launch_profile_id(self, input: Option<String>) -> Self
The ID of the launch profile used to control access from the streaming session.
Sourcepub fn get_launch_profile_id(&self) -> &Option<String>
pub fn get_launch_profile_id(&self) -> &Option<String>
The ID of the launch profile used to control access from the streaming session.
Sourcepub fn owned_by(self, input: impl Into<String>) -> Self
pub fn owned_by(self, input: impl Into<String>) -> Self
The user ID of the user that owns the streaming session. The user that owns the session will be logging into the session and interacting with the virtual workstation.
Sourcepub fn set_owned_by(self, input: Option<String>) -> Self
pub fn set_owned_by(self, input: Option<String>) -> Self
The user ID of the user that owns the streaming session. The user that owns the session will be logging into the session and interacting with the virtual workstation.
Sourcepub fn get_owned_by(&self) -> &Option<String>
pub fn get_owned_by(&self) -> &Option<String>
The user ID of the user that owns the streaming session. The user that owns the session will be logging into the session and interacting with the virtual workstation.
Sourcepub fn streaming_image_id(self, input: impl Into<String>) -> Self
pub fn streaming_image_id(self, input: impl Into<String>) -> Self
The ID of the streaming image.
Sourcepub fn set_streaming_image_id(self, input: Option<String>) -> Self
pub fn set_streaming_image_id(self, input: Option<String>) -> Self
The ID of the streaming image.
Sourcepub fn get_streaming_image_id(&self) -> &Option<String>
pub fn get_streaming_image_id(&self) -> &Option<String>
The ID of the streaming image.
Sourcepub fn set_studio_id(self, input: Option<String>) -> Self
pub fn set_studio_id(self, input: Option<String>) -> Self
The studio ID.
Sourcepub fn get_studio_id(&self) -> &Option<String>
pub fn get_studio_id(&self) -> &Option<String>
The studio ID.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
A collection of labels, in the form of key-value pairs, that apply to this resource.
A collection of labels, in the form of key-value pairs, that apply to this resource.
A collection of labels, in the form of key-value pairs, that apply to this resource.