#[non_exhaustive]pub struct CreateStreamingSessionInput {
pub client_token: Option<String>,
pub ec2_instance_type: Option<StreamingInstanceType>,
pub launch_profile_id: Option<String>,
pub owned_by: Option<String>,
pub streaming_image_id: Option<String>,
pub studio_id: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
ec2_instance_type: Option<StreamingInstanceType>The EC2 Instance type used for the streaming session.
launch_profile_id: Option<String>The ID of the launch profile used to control access from the streaming session.
owned_by: Option<String>The user ID of the user that owns the streaming session. The user that owns the session will be logging into the session and interacting with the virtual workstation.
streaming_image_id: Option<String>The ID of the streaming image.
studio_id: Option<String>The studio ID.
A collection of labels, in the form of key-value pairs, that apply to this resource.
Implementations
Sourceimpl CreateStreamingSessionInput
impl CreateStreamingSessionInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn ec2_instance_type(&self) -> Option<&StreamingInstanceType>
pub fn ec2_instance_type(&self) -> Option<&StreamingInstanceType>
The EC2 Instance type used for the streaming session.
Sourcepub fn launch_profile_id(&self) -> Option<&str>
pub fn launch_profile_id(&self) -> Option<&str>
The ID of the launch profile used to control access from the streaming session.
Sourcepub fn owned_by(&self) -> Option<&str>
pub fn owned_by(&self) -> Option<&str>
The user ID of the user that owns the streaming session. The user that owns the session will be logging into the session and interacting with the virtual workstation.
Sourcepub fn streaming_image_id(&self) -> Option<&str>
pub fn streaming_image_id(&self) -> Option<&str>
The ID of the streaming image.
A collection of labels, in the form of key-value pairs, that apply to this resource.
Sourceimpl CreateStreamingSessionInput
impl CreateStreamingSessionInput
Sourcepub fn builder() -> CreateStreamingSessionInputBuilder
pub fn builder() -> CreateStreamingSessionInputBuilder
Creates a new builder-style object to manufacture CreateStreamingSessionInput.