#[non_exhaustive]pub struct CreateStreamingSessionStreamInputBuilder { /* private fields */ }Expand description
A builder for CreateStreamingSessionStreamInput.
Implementations
Sourceimpl CreateStreamingSessionStreamInputBuilder
impl CreateStreamingSessionStreamInputBuilder
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn expiration_in_seconds(self, input: i32) -> Self
pub fn expiration_in_seconds(self, input: i32) -> Self
The expiration time in seconds.
Sourcepub fn set_expiration_in_seconds(self, input: Option<i32>) -> Self
pub fn set_expiration_in_seconds(self, input: Option<i32>) -> Self
The expiration time in seconds.
Sourcepub fn get_expiration_in_seconds(&self) -> &Option<i32>
pub fn get_expiration_in_seconds(&self) -> &Option<i32>
The expiration time in seconds.
Sourcepub fn session_id(self, input: impl Into<String>) -> Self
pub fn session_id(self, input: impl Into<String>) -> Self
The streaming session ID.
This field is required.Sourcepub fn set_session_id(self, input: Option<String>) -> Self
pub fn set_session_id(self, input: Option<String>) -> Self
The streaming session ID.
Sourcepub fn get_session_id(&self) -> &Option<String>
pub fn get_session_id(&self) -> &Option<String>
The streaming session ID.
Sourcepub fn studio_id(self, input: impl Into<String>) -> Self
pub fn studio_id(self, input: impl Into<String>) -> Self
The studio ID.
This field is required.Sourcepub fn set_studio_id(self, input: Option<String>) -> Self
pub fn set_studio_id(self, input: Option<String>) -> Self
The studio ID.
Sourcepub fn get_studio_id(&self) -> &Option<String>
pub fn get_studio_id(&self) -> &Option<String>
The studio ID.
Sourcepub fn build(self) -> Result<CreateStreamingSessionStreamInput, BuildError>
pub fn build(self) -> Result<CreateStreamingSessionStreamInput, BuildError>
Consumes the builder and constructs a CreateStreamingSessionStreamInput.
Sourceimpl CreateStreamingSessionStreamInputBuilder
impl CreateStreamingSessionStreamInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateStreamingSessionStreamOutput, SdkError<CreateStreamingSessionStreamError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateStreamingSessionStreamOutput, SdkError<CreateStreamingSessionStreamError, HttpResponse>>
Sends a request with this input using the given client.