pub struct CreateStudioFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to CreateStudio.
Create a new studio.
When creating a studio, two IAM roles must be provided: the admin role and the user role. These roles are assumed by your users when they log in to the Nimble Studio portal.
The user role must have the AmazonNimbleStudio-StudioUser managed policy attached for the portal to function properly.
The admin role must have the AmazonNimbleStudio-StudioAdmin managed policy attached for the portal to function properly.
You may optionally specify a KMS key in the StudioEncryptionConfiguration.
In Nimble Studio, resource names, descriptions, initialization scripts, and other data you provide are always encrypted at rest using an KMS key. By default, this key is owned by Amazon Web Services and managed on your behalf. You may provide your own KMS key when calling CreateStudio to encrypt this data using a key you own and manage.
When providing an KMS key during studio creation, Nimble Studio creates KMS grants in your account to provide your studio user and admin roles access to these KMS keys.
If you delete this grant, the studio will no longer be accessible to your portal users.
If you delete the studio KMS key, your studio will no longer be accessible.
Implementations
Sourceimpl CreateStudioFluentBuilder
impl CreateStudioFluentBuilder
Sourcepub fn as_input(&self) -> &CreateStudioInputBuilder
pub fn as_input(&self) -> &CreateStudioInputBuilder
Access the CreateStudio as a reference.
Sourcepub async fn send(
self,
) -> Result<CreateStudioOutput, SdkError<CreateStudioError, HttpResponse>>
pub async fn send( self, ) -> Result<CreateStudioOutput, SdkError<CreateStudioError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<CreateStudioOutput, CreateStudioError, Self>
pub fn customize( self, ) -> CustomizableOperation<CreateStudioOutput, CreateStudioError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn admin_role_arn(self, input: impl Into<String>) -> Self
pub fn admin_role_arn(self, input: impl Into<String>) -> Self
The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
Sourcepub fn set_admin_role_arn(self, input: Option<String>) -> Self
pub fn set_admin_role_arn(self, input: Option<String>) -> Self
The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
Sourcepub fn get_admin_role_arn(&self) -> &Option<String>
pub fn get_admin_role_arn(&self) -> &Option<String>
The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
A friendly name for the studio.
Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
A friendly name for the studio.
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
A friendly name for the studio.
Sourcepub fn studio_encryption_configuration(
self,
input: StudioEncryptionConfiguration,
) -> Self
pub fn studio_encryption_configuration( self, input: StudioEncryptionConfiguration, ) -> Self
The studio encryption configuration.
Sourcepub fn set_studio_encryption_configuration(
self,
input: Option<StudioEncryptionConfiguration>,
) -> Self
pub fn set_studio_encryption_configuration( self, input: Option<StudioEncryptionConfiguration>, ) -> Self
The studio encryption configuration.
Sourcepub fn get_studio_encryption_configuration(
&self,
) -> &Option<StudioEncryptionConfiguration>
pub fn get_studio_encryption_configuration( &self, ) -> &Option<StudioEncryptionConfiguration>
The studio encryption configuration.
Sourcepub fn studio_name(self, input: impl Into<String>) -> Self
pub fn studio_name(self, input: impl Into<String>) -> Self
The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
Sourcepub fn set_studio_name(self, input: Option<String>) -> Self
pub fn set_studio_name(self, input: Option<String>) -> Self
The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
Sourcepub fn get_studio_name(&self) -> &Option<String>
pub fn get_studio_name(&self) -> &Option<String>
The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
A collection of labels, in the form of key-value pairs, that apply to this resource.
A collection of labels, in the form of key-value pairs, that apply to this resource.
A collection of labels, in the form of key-value pairs, that apply to this resource.
Sourcepub fn user_role_arn(self, input: impl Into<String>) -> Self
pub fn user_role_arn(self, input: impl Into<String>) -> Self
The IAM role that studio users will assume when logging in to the Nimble Studio portal.
Sourcepub fn set_user_role_arn(self, input: Option<String>) -> Self
pub fn set_user_role_arn(self, input: Option<String>) -> Self
The IAM role that studio users will assume when logging in to the Nimble Studio portal.
Sourcepub fn get_user_role_arn(&self) -> &Option<String>
pub fn get_user_role_arn(&self) -> &Option<String>
The IAM role that studio users will assume when logging in to the Nimble Studio portal.