#[non_exhaustive]pub struct CreateStudioInputBuilder { /* private fields */ }Expand description
A builder for CreateStudioInput.
Implementations
Sourceimpl CreateStudioInputBuilder
impl CreateStudioInputBuilder
Sourcepub fn admin_role_arn(self, input: impl Into<String>) -> Self
pub fn admin_role_arn(self, input: impl Into<String>) -> Self
The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
This field is required.Sourcepub fn set_admin_role_arn(self, input: Option<String>) -> Self
pub fn set_admin_role_arn(self, input: Option<String>) -> Self
The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
Sourcepub fn get_admin_role_arn(&self) -> &Option<String>
pub fn get_admin_role_arn(&self) -> &Option<String>
The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
A friendly name for the studio.
This field is required.Sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
A friendly name for the studio.
Sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
A friendly name for the studio.
Sourcepub fn studio_encryption_configuration(
self,
input: StudioEncryptionConfiguration,
) -> Self
pub fn studio_encryption_configuration( self, input: StudioEncryptionConfiguration, ) -> Self
The studio encryption configuration.
Sourcepub fn set_studio_encryption_configuration(
self,
input: Option<StudioEncryptionConfiguration>,
) -> Self
pub fn set_studio_encryption_configuration( self, input: Option<StudioEncryptionConfiguration>, ) -> Self
The studio encryption configuration.
Sourcepub fn get_studio_encryption_configuration(
&self,
) -> &Option<StudioEncryptionConfiguration>
pub fn get_studio_encryption_configuration( &self, ) -> &Option<StudioEncryptionConfiguration>
The studio encryption configuration.
Sourcepub fn studio_name(self, input: impl Into<String>) -> Self
pub fn studio_name(self, input: impl Into<String>) -> Self
The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
This field is required.Sourcepub fn set_studio_name(self, input: Option<String>) -> Self
pub fn set_studio_name(self, input: Option<String>) -> Self
The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
Sourcepub fn get_studio_name(&self) -> &Option<String>
pub fn get_studio_name(&self) -> &Option<String>
The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
A collection of labels, in the form of key-value pairs, that apply to this resource.
A collection of labels, in the form of key-value pairs, that apply to this resource.
A collection of labels, in the form of key-value pairs, that apply to this resource.
Sourcepub fn user_role_arn(self, input: impl Into<String>) -> Self
pub fn user_role_arn(self, input: impl Into<String>) -> Self
The IAM role that studio users will assume when logging in to the Nimble Studio portal.
This field is required.Sourcepub fn set_user_role_arn(self, input: Option<String>) -> Self
pub fn set_user_role_arn(self, input: Option<String>) -> Self
The IAM role that studio users will assume when logging in to the Nimble Studio portal.
Sourcepub fn get_user_role_arn(&self) -> &Option<String>
pub fn get_user_role_arn(&self) -> &Option<String>
The IAM role that studio users will assume when logging in to the Nimble Studio portal.
Sourcepub fn build(self) -> Result<CreateStudioInput, BuildError>
pub fn build(self) -> Result<CreateStudioInput, BuildError>
Consumes the builder and constructs a CreateStudioInput.
Sourceimpl CreateStudioInputBuilder
impl CreateStudioInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateStudioOutput, SdkError<CreateStudioError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateStudioOutput, SdkError<CreateStudioError, HttpResponse>>
Sends a request with this input using the given client.