#[non_exhaustive]pub struct DeleteLaunchProfileInput {
pub client_token: Option<String>,
pub launch_profile_id: Option<String>,
pub studio_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.client_token: Option<String>Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
launch_profile_id: Option<String>The ID of the launch profile used to control access from the streaming session.
studio_id: Option<String>The studio ID.
Implementations
Sourceimpl DeleteLaunchProfileInput
impl DeleteLaunchProfileInput
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn launch_profile_id(&self) -> Option<&str>
pub fn launch_profile_id(&self) -> Option<&str>
The ID of the launch profile used to control access from the streaming session.
Sourceimpl DeleteLaunchProfileInput
impl DeleteLaunchProfileInput
Sourcepub fn builder() -> DeleteLaunchProfileInputBuilder
pub fn builder() -> DeleteLaunchProfileInputBuilder
Creates a new builder-style object to manufacture DeleteLaunchProfileInput.