#[non_exhaustive]pub struct ListStudioComponentsInputBuilder { /* private fields */ }Expand description
A builder for ListStudioComponentsInput.
Implementations
Sourceimpl ListStudioComponentsInputBuilder
impl ListStudioComponentsInputBuilder
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The max number of results to return in the response.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The max number of results to return in the response.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The max number of results to return in the response.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
The token for the next set of results, or null if there are no more results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
The token for the next set of results, or null if there are no more results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
The token for the next set of results, or null if there are no more results.
Sourcepub fn states(self, input: StudioComponentState) -> Self
pub fn states(self, input: StudioComponentState) -> Self
Appends an item to states.
To override the contents of this collection use set_states.
Filters the request to studio components that are in one of the given states.
Sourcepub fn set_states(self, input: Option<Vec<StudioComponentState>>) -> Self
pub fn set_states(self, input: Option<Vec<StudioComponentState>>) -> Self
Filters the request to studio components that are in one of the given states.
Sourcepub fn get_states(&self) -> &Option<Vec<StudioComponentState>>
pub fn get_states(&self) -> &Option<Vec<StudioComponentState>>
Filters the request to studio components that are in one of the given states.
Sourcepub fn studio_id(self, input: impl Into<String>) -> Self
pub fn studio_id(self, input: impl Into<String>) -> Self
The studio ID.
This field is required.Sourcepub fn set_studio_id(self, input: Option<String>) -> Self
pub fn set_studio_id(self, input: Option<String>) -> Self
The studio ID.
Sourcepub fn get_studio_id(&self) -> &Option<String>
pub fn get_studio_id(&self) -> &Option<String>
The studio ID.
Sourcepub fn types(self, input: StudioComponentType) -> Self
pub fn types(self, input: StudioComponentType) -> Self
Appends an item to types.
To override the contents of this collection use set_types.
Filters the request to studio components that are of one of the given types.
Sourcepub fn set_types(self, input: Option<Vec<StudioComponentType>>) -> Self
pub fn set_types(self, input: Option<Vec<StudioComponentType>>) -> Self
Filters the request to studio components that are of one of the given types.
Sourcepub fn get_types(&self) -> &Option<Vec<StudioComponentType>>
pub fn get_types(&self) -> &Option<Vec<StudioComponentType>>
Filters the request to studio components that are of one of the given types.
Sourcepub fn build(self) -> Result<ListStudioComponentsInput, BuildError>
pub fn build(self) -> Result<ListStudioComponentsInput, BuildError>
Consumes the builder and constructs a ListStudioComponentsInput.
Sourceimpl ListStudioComponentsInputBuilder
impl ListStudioComponentsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListStudioComponentsOutput, SdkError<ListStudioComponentsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListStudioComponentsOutput, SdkError<ListStudioComponentsError, HttpResponse>>
Sends a request with this input using the given client.