#[non_exhaustive]pub struct CreateStudioInput {
pub admin_role_arn: Option<String>,
pub client_token: Option<String>,
pub display_name: Option<String>,
pub studio_encryption_configuration: Option<StudioEncryptionConfiguration>,
pub studio_name: Option<String>,
pub tags: Option<HashMap<String, String>>,
pub user_role_arn: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.admin_role_arn: Option<String>The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
client_token: Option<String>Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
display_name: Option<String>A friendly name for the studio.
studio_encryption_configuration: Option<StudioEncryptionConfiguration>The studio encryption configuration.
studio_name: Option<String>The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
A collection of labels, in the form of key-value pairs, that apply to this resource.
user_role_arn: Option<String>The IAM role that studio users will assume when logging in to the Nimble Studio portal.
Implementations
Sourceimpl CreateStudioInput
impl CreateStudioInput
Sourcepub fn admin_role_arn(&self) -> Option<&str>
pub fn admin_role_arn(&self) -> Option<&str>
The IAM role that studio admins will assume when logging in to the Nimble Studio portal.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don’t specify a client token, the Amazon Web Services SDK automatically generates a client token and uses it for the request to ensure idempotency.
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
A friendly name for the studio.
Sourcepub fn studio_encryption_configuration(
&self,
) -> Option<&StudioEncryptionConfiguration>
pub fn studio_encryption_configuration( &self, ) -> Option<&StudioEncryptionConfiguration>
The studio encryption configuration.
Sourcepub fn studio_name(&self) -> Option<&str>
pub fn studio_name(&self) -> Option<&str>
The studio name that is used in the URL of the Nimble Studio portal when accessed by Nimble Studio users.
A collection of labels, in the form of key-value pairs, that apply to this resource.
Sourcepub fn user_role_arn(&self) -> Option<&str>
pub fn user_role_arn(&self) -> Option<&str>
The IAM role that studio users will assume when logging in to the Nimble Studio portal.
Sourceimpl CreateStudioInput
impl CreateStudioInput
Sourcepub fn builder() -> CreateStudioInputBuilder
pub fn builder() -> CreateStudioInputBuilder
Creates a new builder-style object to manufacture CreateStudioInput.